@@ -1,16 +1,19 @@
 import inspect as _inspect
 import typing as _typing
 
-from bolinette import blnt, core, web
+from bolinette import blnt, core, web, BolinetteExtension
 from bolinette.blnt.commands import Command as _Command, Argument as _Argument
-from bolinette.utils import InitProxy
+from bolinette.utils import InitProxy as _InitProxy
 
 
-def model(model_name: str, *, database: str = 'default',
+def model(model_name: str, *,
+          database: str = 'default',
           model_type: _typing.Literal['relational', 'collection'] = 'relational',
+          definitions: _typing.Literal['ignore', 'append', 'overwrite'] = 'ignore',
           join_table: bool = False):
     def decorator(model_cls: _typing.Type['core.Model']):
-        model_cls.__blnt__ = core.ModelMetadata(model_name, database, model_type == 'relational', join_table)
+        model_cls.__blnt__ = core.ModelMetadata(model_name, database, model_type == 'relational',
+                                                join_table, definitions)
         blnt.cache.models[model_name] = model_cls
         return model_cls
     return decorator
@@ -39,14 +42,11 @@ def with_mixin(mixin_name: str):
     return decorator
 
 
-def init_func(func: _typing.Callable[['blnt.BolinetteContext'], None]):
-    blnt.cache.init_funcs.append(func)
-    return func
-
-
-def with_context(func: _typing.Callable[['blnt.BolinetteContext'], None]):
-    blnt.cache.with_ctx_funcs.append(func)
-    return func
+def init_func(*, extension: BolinetteExtension = None):
+    def decorator(func: _typing.Callable[['blnt.BolinetteContext'], _typing.Awaitable[None]]):
+        blnt.cache.init_funcs.append(blnt.InitFunc(func, extension))
+        return func
+    return decorator
 
 
 def seeder(func):
@@ -101,9 +101,9 @@ def route(path: str, *, method: web.HttpMethod, expects: 'web.Expects' = None, r
             inner_route = route_function
             route_function = route_function.func
         docstring = route_function.__doc__
-        return InitProxy(web.ControllerRoute, func=route_function, path=path, method=method,
-                         docstring=docstring, expects=expects, returns=returns, inner_route=inner_route,
-                         middlewares=middlewares)
+        return _InitProxy(web.ControllerRoute, func=route_function, path=path, method=method,
+                          docstring=docstring, expects=expects, returns=returns, inner_route=inner_route,
+                          middlewares=middlewares)
     return decorator
 
 
