@@ -1,14 +1,14 @@
 import sqlalchemy
 from sqlalchemy import orm as sqlalchemy_orm
 
-from bolinette import blnt, core, web
+from bolinette import blnt, core, web, Extensions
 from bolinette.decorators import init_func
 from bolinette.exceptions import InitError
 from bolinette.utils import InitProxy
 
 
-@init_func
-def init_model_classes(context: blnt.BolinetteContext):
+@init_func(extension=Extensions.MODELS)
+async def init_model_classes(context: blnt.BolinetteContext):
     models = {}
     proxies = {}
     for model_name, model_cls in blnt.cache.models.items():
@@ -41,8 +41,8 @@ def init_model_classes(context: blnt.BolinetteContext):
         context.add_model(model_name, model)
 
 
-@init_func
-def init_relational_models(context: blnt.BolinetteContext):
+@init_func(extension=Extensions.MODELS)
+async def init_relational_models(context: blnt.BolinetteContext):
     models = {}
     for model_name, model in context.models:
         if model.__props__.database.relational:
@@ -87,31 +87,32 @@ def init_relational_models(context: blnt.BolinetteContext):
         context.add_table(model_name, orm_model)
 
 
-@init_func
+@init_func(extension=Extensions.MODELS)
 async def init_databases(context: blnt.BolinetteContext):
     await context.db.create_all()
 
 
-@init_func
-def init_repositories(context: blnt.BolinetteContext):
+@init_func(extension=Extensions.MODELS)
+async def init_repositories(context: blnt.BolinetteContext):
     for model_name, model in context.models:
         context.add_repo(model_name, core.Repository(model_name, model, context))
 
 
-@init_func
-def init_mappings(context: blnt.BolinetteContext):
+@init_func(extension=Extensions.MODELS)
+async def init_mappings(context: blnt.BolinetteContext):
     for model_name, model in context.models:
         context.mapper.register(model_name, model)
+    i=2
 
 
-@init_func
-def init_services(context: blnt.BolinetteContext):
+@init_func(extension=Extensions.MODELS)
+async def init_services(context: blnt.BolinetteContext):
     for service_name, service_cls in blnt.cache.services.items():
         context.add_service(service_name, service_cls(context))
 
 
-@init_func
-def init_controllers(context: blnt.BolinetteContext):
+@init_func(extension=Extensions.WEB)
+async def init_controllers(context: blnt.BolinetteContext):
     for controller_name, controller_cls in blnt.cache.controllers.items():
         controller = controller_cls(context)
         for route_name, proxy in controller.__props__.get_proxies(web.ControllerRoute):
@@ -126,9 +127,8 @@ def init_controllers(context: blnt.BolinetteContext):
         context.add_controller(controller_name, controller)
 
 
-@init_func
-def init_topics(context: blnt.BolinetteContext):
-    context.sockets.init_socket_handler()
+@init_func(extension=Extensions.SOCKETS)
+async def init_topics(context: blnt.BolinetteContext):
     for topic_name, topic_cls in blnt.cache.topics.items():
         topic = topic_cls(context)
         context.sockets.add_topic(topic_name, topic)
